==> sinosun-ui-0.1.9.tgz: package/es/support/native/BrowserApi.js <==
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import { callHandler, goBackFunction_new, RegisterMenuFunction } from "./JSBridge.js";

//浏览器基础操作类

var BrowserApi = function () {
    function BrowserApi() {
        _classCallCheck(this, BrowserApi);
    }

    _createClass(BrowserApi, [{
        key: 'reloadPage',

        //描述：刷新页面
        //场景：主要处理H5页面内部发起的页面刷新事件，主要是 错误提示页面的 “刷新按钮”
        //对应SnJSBridge接口：ReloadPageFunction
        value: function reloadPage() {
            return callHandler('ReloadPageFunction', '');
        }
        //描述：刷新页面
        //场景：主要处理H5页面内部发起的页面刷新事件，主要是 错误提示页面的 “刷新按钮”
        //对应SnJSBridge接口：goBackFunction
        //@param
        //url：目标页面的url, 为''时关闭当前页
        //backSteps：当前页面回退步数
        //loadData：传递给目标页面的数据

    }, {
        key: 'goBack',
        value: function goBack(url) {
            var backSteps = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : undefined;
            var loadData = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';

            goBackFunction_new(url, backSteps, loadData);
        }

        //描述：title栏注册菜单
        //对应SnJSBridge接口：RegisterMenuFunction
        //@param List<MenuItem>
        //   MenuItem {
        //    String name;  //  如果是菜单，用name显示菜单文字
        //    String iconNormalBase64;  // 如果是图标按钮，用来显示 正常图标（JS交互时，用base64转码，如果图片超过5k，提出来让UI重新切图）
        //    String iconPressedBase64; // 如果是图标按钮，用来显示 按下效果 图标（JS交互时，用base64转码，如果图片超过5k，提出来让UI重新切图）
        //    String menuId;  //必填   菜单ID （不区分是 图标按钮 或是 菜单项），列表中的menuId必须相互唯一
        //    Int type;  // 必填 类型 1 ActionBar上的图标按钮，2 下拉菜单项 3 title显示（一般情况下，只有一个图标按钮，可以有多个下拉菜单项）
        //   }
        //  注意
        //   name 和 iconNormalBase64 至少需要填写一个；
        //   name 和iconNormalBase64 都有值时ActionBar上的按钮优先显示name，下拉菜单项会左边显示图标，右边显示name；
        //       当有多个type 为1的item时，app会取第一个值；
        //       下拉菜单项显示顺序默认按menuList的顺序排序；
        //_this.initTitle = ['考勤统计',{name:'设置',menuId:'but_1_1',type: 1,func:function(){openPage('setting.html')}}];

    }, {
        key: 'registerMenu',
        value: function registerMenu(menuList) {
            RegisterMenuFunction(menuList);
        }
        //描述：打开app页面
        //场景：扫描二维码、选择联系人等
        //对应SnJSBridge接口：OpenActionFunction
        //@param String

    }, {
        key: 'openAppPage',
        value: function openAppPage(str) {
            return callHandler('OpenActionFunction', str);
        }
        //描述：调用app通用弹框
        //场景：提示框，如确认提交 弹框
        //对应SnJSBridge接口：CommonDialogFunction
        //@param Object

    }, {
        key: 'popAppCommonDialog',
        value: function popAppCommonDialog(confirmJson) {
            return callHandler('CommonDialogFunction', JSON.stringify(confirmJson));
        }
        //描述：调用app通用弹框
        //场景：弹出菜单，如保存草稿
        //对应SnJSBridge接口：PopMenuFunction
        //@param Object

    }, {
        key: 'popAppMenuDialog',
        value: function popAppMenuDialog(appData) {
            return callHandler('PopMenuFunction', appData);
        }
        //描述：弹窗打开页面
        //场景：PC客户端打开独立页面，仅PC使用
        //对应SnJSBridge接口：PopWindowFunction
        //@param url

    }, {
        key: 'popWindow',
        value: function popWindow(targetUrl) {
            callHandler('PopWindowFunction', JSON.stringify({
                url: targetUrl
            }));
        }
        //描述：js调用 Native 省市选择弹窗
        //场景：转账选择省市
        //对应SnJSBridge接口：SelectProvinceWidget
        //@param url

    }, {
        key: 'openSelectProvinceWidget',
        value: function openSelectProvinceWidget(provinceListAll) {
            return callHandler('SelectProvinceWidgetFunction', provinceListAll);
        }
        //描述：文件预览
        //对应SnJSBridge接口：FilePreviewWidget
        //@param Object

    }, {
        key: 'filePreview',
        value: function filePreview(previemJson) {
            return callHandler('PreviewFunction', previemJson);
        }
        //描述：注册回调处理事件
        //场景：用于告知客户端，H5页面需要自己处理返回，mPaaS也是一样的处理方案
        //对应SnJSBridge接口：notifyAppBackEvent

    }, {
        key: 'registeAppBackEvent',
        value: function registeAppBackEvent(callback) {
            callHandler('notifyAppBackEvent', '');
            registerHandler('notifyAppBack', callback);
        }
    }]);

    return BrowserApi;
}();

export default new BrowserApi();

==> sinosun-ui-0.3.6.tgz: package/es/support/native/BrowserApi.js <==
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import { callHandler, registerHandler as _registerHandler, goBackFunction_new, RegisterMenuFunction } from "./JSBridge.js";

//浏览器基础操作类

var BrowserApi = function () {
    function BrowserApi() {
        _classCallCheck(this, BrowserApi);
    }

    _createClass(BrowserApi, null, [{
        key: 'registerHandler',

        /**
         * 注册浏览器处理事件
         */
        value: function registerHandler(event, callback) {
            _registerHandler(event, callback);
        }

        //描述：刷新页面
        //场景：主要处理H5页面内部发起的页面刷新事件，主要是 错误提示页面的 “刷新按钮”
        //对应SnJSBridge接口：ReloadPageFunction

    }, {
        key: 'reloadPage',
        value: function reloadPage() {
            return callHandler('ReloadPageFunction', '');
        }

        /**
         * 注册页面刷新事件
         * @param {*} callback 
         */

    }, {
        key: 'registPageRefreshEvent',
        value: function registPageRefreshEvent(callback) {
            _registerHandler("refreshPage", callback);
        }

        //描述：注册回调处理事件
        //场景：用于告知客户端，H5页面需要自己处理返回，mPaaS也是一样的处理方案
        //对应SnJSBridge接口：notifyAppBackEvent

    }, {
        key: 'registeAppBackEvent',
        value: function registeAppBackEvent(callback) {
            callHandler('notifyAppBackEvent', '');
            _registerHandler('notifyAppBack', callback);
        }

        //描述：刷新页面
        //场景：主要处理H5页面内部发起的页面刷新事件，主要是 错误提示页面的 “刷新按钮”
        //对应SnJSBridge接口：goBackFunction
        //@param
        //url：目标页面的url, 为''时关闭当前页
        //backSteps：当前页面回退步数
        //loadData：传递给目标页面的数据

    }, {
        key: 'goBack',
        value: function goBack(url) {
            var backSteps = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : undefined;
            var loadData = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';

            goBackFunction_new(url, backSteps, loadData);
        }

        // mjCode

    }, {
        key: 'setTitle',
        value: function setTitle(title) {
            document.title = title;
        }

        //描述：title栏注册菜单
        //对应SnJSBridge接口：RegisterMenuFunction
        //@param List<MenuItem>
        //   MenuItem {
        //    String name;  //  如果是菜单，用name显示菜单文字
        //    String iconNormalBase64;  // 如果是图标按钮，用来显示 正常图标（JS交互时，用base64转码，如果图片超过5k，提出来让UI重新切图）
        //    String iconPressedBase64; // 如果是图标按钮，用来显示 按下效果 图标（JS交互时，用base64转码，如果图片超过5k，提出来让UI重新切图）
        //    String menuId;  //必填   菜单ID （不区分是 图标按钮 或是 菜单项），列表中的menuId必须相互唯一
        //    Int type;  // 必填 类型 1 ActionBar上的图标按钮，2 下拉菜单项 3 title显示（一般情况下，只有一个图标按钮，可以有多个下拉菜单项）
        //   }
        //  注意
        //   name 和 iconNormalBase64 至少需要填写一个；
        //   name 和iconNormalBase64 都有值时ActionBar上的按钮优先显示name，下拉菜单项会左边显示图标，右边显示name；
        //       当有多个type 为1的item时，app会取第一个值；
        //       下拉菜单项显示顺序默认按menuList的顺序排序；
        //_this.initTitle = ['考勤统计',{name:'设置',menuId:'but_1_1',type: 1,func:function(){openPage('setting.html')}}];

    }, {
        key: 'registerMenu',
        value: function registerMenu(menuList) {
            RegisterMenuFunction(menuList);
        }
        //描述：打开app页面
        //场景：扫描二维码、选择联系人等
        //对应SnJSBridge接口：OpenActionFunction
        //@param String

    }, {
        key: 'openAppPage',
        value: function openAppPage(str) {
            return callHandler('OpenActionFunction', str);
        }
        //描述：调用app通用弹框
        //场景：提示框，如确认提交 弹框
        //对应SnJSBridge接口：CommonDialogFunction
        //@param Object

    }, {
        key: 'popAppCommonDialog',
        value: function popAppCommonDialog(confirmJson) {
            return callHandler('CommonDialogFunction', JSON.stringify(confirmJson));
        }
        //描述：调用app通用弹框
        //场景：弹出菜单，如保存草稿
        //对应SnJSBridge接口：PopMenuFunction
        //@param Object

    }, {
        key: 'popAppMenuDialog',
        value: function popAppMenuDialog(appData) {
            return callHandler('PopMenuFunction', appData);
        }
        //描述：弹窗打开页面
        //场景：PC客户端打开独立页面，仅PC使用
        //对应SnJSBridge接口：PopWindowFunction
        //@param url

    }, {
        key: 'popWindow',
        value: function popWindow(targetUrl) {
            callHandler('PopWindowFunction', JSON.stringify({
                url: targetUrl
            }));
        }
        //描述：js调用 Native 省市选择弹窗
        //场景：转账选择省市
        //对应SnJSBridge接口：SelectProvinceWidget
        //@param url

    }, {
        key: 'openSelectProvinceWidget',
        value: function openSelectProvinceWidget(provinceListAll) {
            return callHandler('SelectProvinceWidgetFunction', provinceListAll);
        }
        //描述：文件预览
        //对应SnJSBridge接口：FilePreviewWidget
        //@param Object

    }, {
        key: 'filePreview',
        value: function filePreview(previemJson) {
            return callHandler('PreviewFunction', previemJson);
        }
    }]);

    return BrowserApi;
}();

export default BrowserApi;
